@@ -46,7 +46,7 @@ libvisio::VSDXStylesCollector::VSDXStylesCollector(
   m_groupShapeOrder(), m_shapeList(), m_currentStyleSheet(0), m_styles(),
   m_lineStyle(0), m_fillStyle(0), m_textBlockStyle(0), m_charStyle(0), m_paraStyle(0),
   m_lineStyleMaster(0xffffffff), m_fillStyleMaster(0xffffffff), m_textStyleMaster(0xffffffff),
-  m_isStyleStarted(false)
+  m_isStyleStarted(false), m_currentShapeLevel(0)
 {
   m_groupXFormsSequence.clear();
   m_groupMembershipsSequence.clear();
@@ -206,7 +206,7 @@ void libvisio::VSDXStylesCollector::collectPageProps(unsigned /* id */, unsigned
   _handleLevelChange(level);
 }
 
-void libvisio::VSDXStylesCollector::collectPage(unsigned /* id */, unsigned level, unsigned /* backgroundPageID */, unsigned /* currentPageID */)
+void libvisio::VSDXStylesCollector::collectPage(unsigned /* id */, unsigned level, unsigned /* backgroundPageID */)
 {
   _handleLevelChange(level);
 }
@@ -215,6 +215,7 @@ void libvisio::VSDXStylesCollector::collectShape(unsigned id, unsigned level, un
     unsigned /* lineStyle */, unsigned /* fillStyle */, unsigned /* textStyle */)
 {
   _handleLevelChange(level);
+  m_currentShapeLevel = level;
   m_currentShapeId = id;
   m_isShapeStarted = true;
 }
@@ -243,10 +244,10 @@ void libvisio::VSDXStylesCollector::collectVSDXParaStyle(unsigned /* id */ , uns
   _handleLevelChange(level);
 }
 
-void libvisio::VSDXStylesCollector::collectVSDXCharStyle(unsigned /*id*/ , unsigned level, unsigned /*charCount*/, unsigned short /*fontID*/, Colour /*fontColour*/,
-    unsigned /*langId*/, double /*fontSize*/, bool /*bold*/, bool /*italic*/, bool /*underline*/,
+void libvisio::VSDXStylesCollector::collectVSDXCharStyle(unsigned /*id*/ , unsigned level, unsigned /*charCount*/, unsigned short /*fontID*/,
+    Colour /*fontColour*/, double /*fontSize*/, bool /*bold*/, bool /*italic*/, bool /*underline*/,
     bool /* doubleunderline */, bool /* strikeout */, bool /* doublestrikeout */, bool /* allcaps */,
-    bool /* initcaps */, bool /* smallcaps */, bool /* superscript */, bool /* subscript */, WPXString /*fontFace*/)
+    bool /* initcaps */, bool /* smallcaps */, bool /* superscript */, bool /* subscript */, VSDXFont /*fontFace*/)
 {
   _handleLevelChange(level);
 }
@@ -266,6 +267,8 @@ void libvisio::VSDXStylesCollector::collectName(unsigned /*id*/, unsigned level,
 void libvisio::VSDXStylesCollector::collectStyleSheet(unsigned id, unsigned level, unsigned lineStyleParent, unsigned fillStyleParent, unsigned textStyleParent)
 {
   _handleLevelChange(level);
+  // reusing the shape level for style sheet to avoid another variable
+  m_currentShapeLevel = level;
   m_lineStyle = 0;
   m_fillStyle = 0;
   m_textBlockStyle = 0;
@@ -324,14 +327,14 @@ void libvisio::VSDXStylesCollector::collectParaIXStyle(unsigned /*id*/, unsigned
 }
 
 
-void libvisio::VSDXStylesCollector::collectCharIXStyle(unsigned /*id*/ , unsigned level, unsigned charCount, unsigned short fontID, Colour fontColour,
-    unsigned langID, double fontSize, bool bold, bool italic, bool underline, bool doubleunderline,
+void libvisio::VSDXStylesCollector::collectCharIXStyle(unsigned /*id*/ , unsigned level, unsigned charCount, unsigned short fontID,
+    Colour fontColour, double fontSize, bool bold, bool italic, bool underline, bool doubleunderline,
     bool strikeout, bool doublestrikeout, bool allcaps, bool initcaps, bool smallcaps,
-    bool superscript, bool subscript, WPXString fontFace)
+    bool superscript, bool subscript, VSDXFont fontFace)
 {
   _handleLevelChange(level);
   if (!m_charStyle)
-    m_charStyle = new VSDXCharStyle(charCount, fontID, fontColour, langID, fontSize, bold, italic, underline, doubleunderline, strikeout, doublestrikeout,
+    m_charStyle = new VSDXCharStyle(charCount, fontID, fontColour, fontSize, bold, italic, underline, doubleunderline, strikeout, doublestrikeout,
                                     allcaps, initcaps, smallcaps, superscript, subscript, fontFace);
 }
 
@@ -365,7 +368,7 @@ void libvisio::VSDXStylesCollector::collectNumericField(unsigned /* id */, unsig
   _handleLevelChange(level);
 }
 
-void libvisio::VSDXStylesCollector::startPage()
+void libvisio::VSDXStylesCollector::startPage(unsigned /* pageId */)
 {
   m_groupXForms.clear();
   m_groupMemberships.clear();
@@ -400,9 +403,9 @@ void libvisio::VSDXStylesCollector::_handleLevelChange(unsigned level)
 {
   if (m_currentLevel == level)
     return;
-  if (level < 3)
+  if (level <= m_currentShapeLevel+1)
     _flushShapeList();
-  if (level < 2)
+  if (level <= m_currentShapeLevel)
   {
     m_isShapeStarted = false;
     if (m_isStyleStarted)
